@@ -63,7 +63,6 @@ Field& Field::operator=(const Field& src)
 
   m_glom_type = src.m_glom_type;
   m_field_info = src.m_field_info->copy();
-  m_data = src.m_data;
 
   m_lookup_relationship = src.m_lookup_relationship;
   m_strLookupField = src.m_strLookupField;
@@ -85,7 +84,6 @@ bool Field::operator==(const Field& src) const
   return TranslatableItem::operator==(src)
          && (m_field_info->equal(src.m_field_info))
          && (m_glom_type == src.m_glom_type)
-         && (m_data == src.m_data)
          && (m_lookup_relationship == src.m_lookup_relationship)
          && (m_strLookupField == src.m_strLookupField)
          && (m_calculation == src.m_calculation)
@@ -156,16 +154,6 @@ void Field::set_field_info(const Glib::RefPtr<Gnome::Gda::Column>& fieldinfo)
     set_glom_type( get_glom_type_for_gda_type(fieldinfo->get_g_type()) );
 }
 
-Gnome::Gda::Value Field::get_data() const
-{
-  return m_data;
-}
-
-void Field::set_data(const Gnome::Gda::Value& data)
-{
-  m_data = data;
-}
-
 sharedptr<Relationship> Field::get_lookup_relationship() const
 {
   return m_lookup_relationship;
@@ -716,6 +704,39 @@ Glib::ustring Field::get_sql_type() const
   }
 }
 
+Glib::ustring Field::get_gda_type_name() const
+{
+  //return g_type_name( get_gda_type_for_glom_type(m_glom_type) );
+  return g_type_name( m_field_info->get_g_type());
+}
+
+Glib::RefPtr<Gnome::Gda::Holder> Field::get_holder(const Gnome::Gda::Value& value, const Glib::ustring& name) const
+{
+  const Glib::ustring real_name = name.empty() ? get_name() : name;
+
+  const GType gtype = value.get_value_type();
+
+  const GType field_type = m_field_info->get_g_type();
+  if(m_field_info->get_g_type() != gtype)
+  {
+    // This currently happens with SQLite for pictures. The value type is
+    // GdaBinary, but the field type is GdaBlob. This is not an optimal
+    // solution this way. We should maybe check fallback types here, or
+    // investigate why the field type is not GdaBinary as well.
+    //g_warning("Field::get_holder(): Field type (%s) and value type (%s) don't match!\n", g_type_name(field_type), g_type_name(gtype));
+  }
+
+  Glib::RefPtr<Gnome::Gda::Holder> holder = Gnome::Gda::Holder::create(gtype, real_name);
+  holder->set_value_as_value(value);
+  return holder;
+}
+
+Glib::ustring Field::get_gda_holder_string(const Glib::ustring& name) const
+{
+  const Glib::ustring real_name = name.empty() ? get_name() : name;
+  return "##" + real_name + "::" + get_gda_type_name();
+}
+
 /// Ignores any part of FieldAttributes that libgda does not properly fill.
 bool Field::field_info_from_database_is_equal(const Glib::RefPtr<const Gnome::Gda::Column>& field)
 {
