@@ -43,9 +43,9 @@ type_list_currencies get_list_of_currency_symbols()
   {
     const Glib::ustring filename = ISO_CODES_PREFIX "/share/xml/iso-codes/iso_4217.xml";
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     try
-#endif
+#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
     {
       xmlpp::DomParser parser;
       //parser.set_validate();
@@ -84,14 +84,14 @@ type_list_currencies get_list_of_currency_symbols()
         }
       }
     }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     catch(const std::exception& ex)
     {
       std::cerr << "Exception while parsing iso codes (currencies): " << ex.what() << std::endl;
     }
-#endif
+#endif // LIBXMLPP_EXCEPTIONS_ENABLED
   }
-  
+
   return list_currencies;
 }
 
@@ -107,26 +107,38 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
     Glib::ustring locales_path = "/usr/share/i18n/locales/";
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
-#endif
     {
       Glib::Dir dir(locales_path);
       list_ids = type_list_ids(dir.begin(), dir.end());
     }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     catch(const Glib::FileError& ex)
     {
       std::cerr << "Glom: get_locale_name(): Could not open (or read) glibc locales directory: " << locales_path << "Error: " << ex.what() << std::endl;
     }
+#else
+    GError* error;
+    GDir* dir = g_dir_open(locales_path.c_str(), 0, &error);
+    if(!error)
+    {
+      Glib::Dir dir_cpp(dir);
+      list_ids = type_list_ids(dir_cpp.begin(), dir_cpp.end());
+    }
+    else
+    {
+      std::cerr << "Glom: get_locale_name(): Could not open (or read) glibc locales directory: " << locales_path << "Error: " << error->message << std::endl;
+      g_error_free(error);
+    }
 #endif
-    
+
     //Get the (translated) language names:
     typedef std::map<Glib::ustring, Glib::ustring> type_map_language; //ID to language name.
     type_map_language map_languages;
 
     const Glib::ustring filename_languages = ISO_CODES_PREFIX "/share/xml/iso-codes/iso_639.xml";
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
+
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     try
-#endif
+#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
     {
       xmlpp::DomParser parser;
       //parser.set_validate();
@@ -166,21 +178,22 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
         }
       }
     }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     catch(const std::exception& ex)
     {
       std::cerr << "Exception while parsing iso codes (locales): " << ex.what() << std::endl;
     }
-#endif
+#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
 
     //Get the (translated) country names:
     typedef std::map<Glib::ustring, Glib::ustring> type_map_country; //ID to country name.
     type_map_country map_country;
 
     const Glib::ustring filename_countries = ISO_CODES_PREFIX "/share/xml/iso-codes/iso_3166.xml";
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
+
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     try
-#endif
+#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
     {
       xmlpp::DomParser parser;
       //parser.set_validate();
@@ -219,12 +232,13 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
         }
       }
     }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     catch(const std::exception& ex)
     {
       std::cerr << "Exception while parsing iso codes (locales): " << ex.what() << std::endl;
     }
-#endif
+#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
+
       //Use a map so we can easily check for duplicates.
     for(type_list_ids::iterator iter = list_ids.begin(); iter != list_ids.end(); ++iter)
     {
