@@ -109,6 +109,7 @@ Glib::ustring Box_Data::get_find_where_clause() const
 
         if(use_this_field)
         {
+          //TODO: Use a SQL parameter instead of using sql_find().
           strClausePart = "\"" + m_table_name + "\".\"" + field->get_name() + "\" " + field->sql_find_operator() + " " +  field->sql_find(data); //% is mysql wildcard for 0 or more characters.
         }
       }
@@ -246,89 +247,6 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
     return type_vecLayoutFields();
 }
 
-/** Get the shown fields that are in related tables, via a relationship using @a field_name changes.
- */
-Box_Data::type_vecLayoutFields Box_Data::get_related_fields(const sharedptr<const LayoutItem_Field>& field) const
-{
-  type_vecLayoutFields result;
-
-  const Document_Glom* document = dynamic_cast<const Document_Glom*>(get_document());
-  if(document)
-  {
-    const Glib::ustring field_name = field->get_name(); //At the moment, relationships can not be based on related fields on the from side.
-    for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end();  ++iter)
-    {
-      sharedptr<LayoutItem_Field> layout_field = *iter;
-      //Examine each field that looks up its data from a relationship:
-      if(layout_field->get_has_relationship_name())
-      {
-        //Get the relationship information:
-        sharedptr<const Relationship> relationship = document->get_relationship(m_table_name, layout_field->get_relationship_name());
-        if(relationship)
-        {
-          //If the relationship uses the specified field:
-          if(relationship->get_from_field() == field_name)
-          {
-            //Add it:
-            result.push_back(layout_field);
-          }
-        }
-      }
-    }
-  }
-
-  return result;
-}
-
-void Box_Data::refresh_related_fields(const LayoutFieldInRecord& field_in_record_changed, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& /* field_value */)
-{
-  if(field_in_record_changed.m_table_name != m_table_name)
-    return; //TODO: Handle these too?
-
-  //Get values for lookup fields, if this field triggers those relationships:
-  //TODO_performance: There is a LOT of iterating and copying here.
-  //const Glib::ustring strFieldName = field_in_record_changed.m_field->get_name();
-  type_vecLayoutFields fieldsToGet = get_related_fields(field_in_record_changed.m_field);
-
-  if(!fieldsToGet.empty())
-  {
-    const Glib::ustring query = Utils::build_sql_select_with_key(field_in_record_changed.m_table_name, fieldsToGet, field_in_record_changed.m_key, field_in_record_changed.m_key_value);
-
-    Glib::RefPtr<Gnome::Gda::DataModel> result = query_execute_select(query, get_app_window());
-    if(!result)
-    {
-      g_warning("Box_Data_List::refresh_related_fields(): no result.");
-      handle_error();
-    }
-    else
-    {
-      //Field contents:
-      if(result->get_n_rows())
-      {
-        type_vecLayoutFields::const_iterator iterFields = fieldsToGet.begin();
-
-        guint cols_count = result->get_n_columns();
-        for(guint uiCol = 0; uiCol < cols_count; uiCol++)
-        {
-          const Gnome::Gda::Value value = result->get_value_at(uiCol, 0 /* row */);
-          sharedptr<LayoutItem_Field> layout_item = *iterFields;
-
-          //g_warning("list fill: field_name=%s", iterFields->get_name().c_str());
-          //g_warning("  value_as_string=%s", value.to_string().c_str());
-
-          //m_AddDel.set_value(row, layout_item, value);
-          set_entered_field_data(row, layout_item, value);
-          //g_warning("addedel size=%d", m_AddDel.get_count());
-
-          ++iterFields;
-        }
-      }
-      else
-       g_warning("Box_Data_List::refresh_related_fields(): no records found.");
-    }
-  }
-}
-
 Document_Glom::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& layout_platform)
 {
   Document_Glom::type_list_layout_groups layout_groups;
