@@ -147,7 +147,6 @@ void Box_Data_Details::set_primary_key_value(const Gtk::TreeModel::iterator& /*
 {
   m_primary_key_value = value;
   set_found_set_from_primary_key_value();
-  //std::cout << "Box_Data_Details::set_primary_key_value(): m_primary_key_value=" << m_field_primary_key->sql(m_primary_key_value) << std::endl;
 }
 
 void Box_Data_Details::set_found_set_from_primary_key_value()
@@ -157,6 +156,7 @@ void Box_Data_Details::set_found_set_from_primary_key_value()
 
   if(!m_primary_key_value.is_null())
   {
+    //TODO: Use a SQL parameter instead of using sql().
     m_found_set.m_where_clause = "\"" + m_table_name + "\".\"" + m_field_primary_key->get_name() + 
       "\" = " + m_field_primary_key->sql(m_primary_key_value);
     //std::cout << "  DEBUG: Box_Data_Details::set_primary_key_value(): m_found_set.m_where_clause = " << m_found_set.m_where_clause << std::endl;
@@ -333,7 +333,7 @@ bool Box_Data_Details::fill_from_database()
         Glib::RefPtr<Gnome::Gda::DataModel> result;
 
         if(!primary_key_is_empty)
-          result = query_execute_select(query, get_app_window());
+          result = query_execute_select(query);
 
         if((result && result->get_n_rows()) || primary_key_is_empty) //either a working result or no result needed.
         {
@@ -760,6 +760,10 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       bTest = set_field_value_in_database(field_in_record, field_value, false /* don't use current calculations */, get_app_window());
     }
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
+    catch(const Glib::Exception& ex)
+    {
+      handle_error(ex);
+    }
     catch(const std::exception& ex)
     {
       handle_error(ex);
@@ -773,7 +777,9 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       if(!bTest)
       {
         //Update failed.
-        fill_from_database(); //Replace with correct values.
+        //Replace with correct values.
+        const Gnome::Gda::Value value_old = get_field_value_in_database(field_in_record, window);
+        set_entered_field_data(layout_field, value_old);
       }
       else
       {
