@@ -24,7 +24,7 @@
 #include <gtkmm/dialog.h>
 #include "../utility_widgets/dialog_properties.h"
 #include <glom/libglom/document/document_glom.h>
-#include "../box_db.h"
+#include "../box_withbuttons.h"
 
 namespace Glom
 {
@@ -38,12 +38,13 @@ public:
   virtual ~Dialog_Layout();
 
   /**
-   * @param layout "list" or "details"
+   * @param layout_name "list" or "details"
+   * @param layout_platform As in the document. Empty or "maemo".
    * @param document The document, so that the dialog can load the previous layout, and save changes.
    * @param table_name The table name.
    * @param table_fields: The actual fields in the table, in case the document does not yet know about them all.
    */
-  virtual void set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields);
+  virtual void set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields);
 
   virtual bool get_modified() const;
 
@@ -69,10 +70,8 @@ protected:
   Gtk::Label* m_label_table_title;
 
   Glib::ustring m_table_name;
-  Glib::ustring m_layout_name;
-
-
-  //Document_Glom* m_document;  
+  Glib::ustring m_layout_name, m_layout_platform; //As in the document.
+ 
   bool m_modified;
 };
 
