@@ -144,23 +144,24 @@ bool Box_Tables::fill_from_database()
 #else
   std::auto_ptr<ExceptionConnection> error;
   sharedptr<SharedConnection> sharedconnection = connect_to_server(App_Glom::get_application(), error);
-  // Ignore error, sharedconnection presence is checked below
+  // Ignore error because sharedconnection presence is checked below.
 #endif
+
   if(sharedconnection)
   {
     m_AddDel.remove_all();
     Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
 
-    type_vecStrings vecTables = get_table_names_from_database();
+    const type_vecStrings vecTables = get_table_names_from_database();
 
-    for(type_vecStrings::iterator iter = vecTables.begin(); iter != vecTables.end(); iter++)
+    for(type_vecStrings::const_iterator iter = vecTables.begin(); iter != vecTables.end(); iter++)
     {
       const Glib::ustring strName = *iter;
 
       sharedptr<TableInfo> table_info;
 
       //Check whether it should be hidden:
-      Document_Glom::type_listTableInfo::iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
+      Document_Glom::type_listTableInfo::const_iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
       if(iterFind != listTablesDocument.end())
       {
         table_info = *iterFind;
@@ -179,7 +180,7 @@ bool Box_Tables::fill_from_database()
       const bool hidden = table_info->m_hidden;
 
       bool bAddIt = true;
-      if(hidden && !developer_mode)  //Don't add hidden tables unless we are in developer mode:
+      if(hidden && !developer_mode) //Don't add hidden tables unless we are in developer mode:
         bAddIt = false;
 
       if(hidden && !m_pCheckButtonShowHidden->get_active()) //Don't add hidden tables if that checkbox is unset.
@@ -191,9 +192,7 @@ bool Box_Tables::fill_from_database()
       const Glib::ustring prefix = "glom_system_";
       const Glib::ustring table_prefix = strName.substr(0, prefix.size());
       if(table_prefix == prefix)
-      {
         bAddIt = false;
-      }
 
       if(bAddIt)
       {
@@ -301,9 +300,14 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
           //Delete the table:
           if(iButtonClicked == Gtk::RESPONSE_OK)
           {
-            query_execute( "DROP TABLE \"" + table_name + "\"", App_Glom::get_application());
-            get_document()->remove_table(table_name); //Forget about it in the document too.
-            something_changed = true;
+            const bool test = query_execute( "DROP TABLE \"" + table_name + "\"");
+            if(!test)
+              std::cerr << "Box_Tables::on_adddel_Delete(): DROP TABLE failed." << std::endl;
+            else
+            {
+              get_document()->remove_table(table_name); //Forget about it in the document too.
+              something_changed = true;
+            }
           }
         }
       }
@@ -376,7 +380,7 @@ void Box_Tables::save_to_document()
     }
 
     if(document)
-      document->set_tables( listTables); //TODO: Don't save all new tables - just the ones already in the document.
+      document->set_tables(listTables); //TODO: Don't save all new tables - just the ones already in the document.
   }
 }
 
@@ -431,7 +435,7 @@ void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint co
         //Rename the table:
         if(iButtonClicked == Gtk::RESPONSE_OK)
         {
-          const bool test = query_execute( "ALTER TABLE \"" + table_name + "\" RENAME TO \"" + table_name_new + "\"", App_Glom::get_application());
+          const bool test = query_execute( "ALTER TABLE \"" + table_name + "\" RENAME TO \"" + table_name_new + "\"");
           if(test)
           {
             //Change the AddDel item's key:
