@@ -23,8 +23,6 @@
 #include <glibmm/i18n.h>
 #include "../cellrendererlist/cellrendererlist.h"
 #include "db_treeviewcolumn_glom.h"
-#include "glom_db_treemodel.h"
-#include "liststore_with_addrow.h"
 #include <glom/libglom/data_structure/glomconversions.h>
 #include "../../dialog_invalid_data.h"
 #include "../../application.h"
@@ -408,8 +406,8 @@ Gtk::TreeModel::iterator DbAddDel::get_item_selected()
      return refTreeSelection->get_selected();
   }
 
-  if(m_refListStore_as_model)
-    return m_refListStore_as_model->children().end();
+  if(m_refListStore)
+    return m_refListStore->children().end();
   else
     return Gtk::TreeModel::iterator();
 }
@@ -423,8 +421,8 @@ Gtk::TreeModel::iterator DbAddDel::get_item_selected() const
      return unconst->get_selected();
   }
 
-  if(m_refListStore_as_model)
-    return m_refListStore_as_model->children().end();
+  if(m_refListStore)
+    return m_refListStore->children().end();
   else
     return Gtk::TreeModel::iterator();
 }
@@ -432,10 +430,10 @@ Gtk::TreeModel::iterator DbAddDel::get_item_selected() const
 
 Gtk::TreeModel::iterator DbAddDel::get_row(const Gnome::Gda::Value& key)
 {
-  if(!m_refListStore_as_model)
+  if(!m_refListStore)
     return Gtk::TreeModel::iterator();
 
-  for(Gtk::TreeModel::iterator iter = m_refListStore_as_model->children().begin(); iter != m_refListStore_as_model->children().end(); ++iter)
+  for(Gtk::TreeModel::iterator iter = m_refListStore->children().begin(); iter != m_refListStore->children().end(); ++iter)
   {
     //Gtk::TreeModel::Row row = *iter;
     const Gnome::Gda::Value& valTemp = get_value_key(iter);
@@ -445,7 +443,7 @@ Gtk::TreeModel::iterator DbAddDel::get_row(const Gnome::Gda::Value& key)
     }
   }
 
-  return  m_refListStore_as_model->children().end();
+  return  m_refListStore->children().end();
 }
 
 bool DbAddDel::select_item(const Gtk::TreeModel::iterator& iter, bool start_editing)
@@ -491,7 +489,7 @@ bool DbAddDel::select_item(const Gtk::TreeModel::iterator& iter, const sharedptr
     {
       refTreeSelection->select(iter);
 
-      Gtk::TreeModel::Path path = m_refListStore_as_model->get_path(iter);
+      Gtk::TreeModel::Path path = m_refListStore->get_path(iter);
 
       guint view_column_index = 0;
       const bool test = get_view_column_index(treemodel_col, view_column_index);
@@ -518,10 +516,10 @@ bool DbAddDel::select_item(const Gtk::TreeModel::iterator& iter, const sharedptr
 
 guint DbAddDel::get_count() const
 {
-  if(!m_refListStore_as_model)
+  if(!m_refListStore)
     return 0;
 
-  guint iCount = m_refListStore_as_model->children().size();
+  guint iCount = m_refListStore->children().size();
 
   //Take account of the extra blank for new entries:
   if(get_allow_user_actions()) //If it has the extra row.
@@ -580,10 +578,10 @@ int DbAddDel::get_fixed_cell_height()
 
 void DbAddDel::on_cell_layout_button_clicked(const Gtk::TreeModel::Path& path, int model_column_index)
 {
-  if(!m_refListStore_as_model)
+  if(!m_refListStore)
     return;
 
-  Gtk::TreeModel::iterator iter = m_refListStore_as_model->get_iter(path);
+  Gtk::TreeModel::iterator iter = m_refListStore->get_iter(path);
   if(iter)
   {
     sharedptr<const LayoutItem> layout_item = m_ColumnTypes[model_column_index].m_item;
@@ -824,8 +822,6 @@ void DbAddDel::apply_formatting(Gtk::CellRenderer* renderer, const FieldFormatti
 
 void DbAddDel::construct_specified_columns()
 {
-  //std::cout << "debug: DbAddDel::construct_specified_columns()" << std::endl;
-
   InnerIgnore innerIgnore(this);
 
   //TODO_optimisation: This is called many times, just to simplify the API.
@@ -849,7 +845,7 @@ void DbAddDel::construct_specified_columns()
   Gtk::TreeModel::ColumnRecord record;
     
   //Database columns:
-  DbTreeModel::type_vec_fields fields;
+  type_model_store::type_vec_fields fields;
   {
     type_vecModelColumns::size_type i = 0;
     for(type_ColumnTypes::iterator iter = m_ColumnTypes.begin(); iter != m_ColumnTypes.end(); ++iter)
@@ -876,22 +872,11 @@ void DbAddDel::construct_specified_columns()
   
   m_FieldsShown = fields; //Needed by Base_DB_Table_Data::record_new().
 
-  //std::cout << "DEBUG: DbAddDel::construct_specified_columns(): m_find_mode=" << m_find_mode << std::endl;
-
-  if(m_find_mode)
-  {
-    //std::cout << "DEBUG: DbAddDel::construct_specified_columns(): Creating ListStoreWithAddRow" << std::endl;
-    Glib::RefPtr<ListStoreWithAddRow> liststore = ListStoreWithAddRow::create(record, fields);
-    liststore->append();
-    m_refListStore = liststore.operator->();
-    m_refListStore_as_model = liststore;
-  }
-  else
   {
     //Find the primary key:
     int column_index_key = 0;
     bool key_found = false;
-    for(DbTreeModel::type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
+    for(type_model_store::type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
     {
       sharedptr<LayoutItem_Field> layout_item = *iter;
       if( !(layout_item->get_has_relationship_name()) )
@@ -907,12 +892,11 @@ void DbAddDel::construct_specified_columns()
       ++column_index_key;
     }
 
-    if(key_found )
+    if(key_found)
     {
       //Create the model from the ColumnRecord:
-      Glib::RefPtr<DbTreeModel> liststore  = DbTreeModel::create(record, m_found_set, fields, column_index_key, m_allow_view);
-      m_refListStore = liststore.operator->();
-      m_refListStore_as_model = liststore;
+      //Note that the model will use a dummy Gda DataModel if m_find_mode is true.
+      m_refListStore = type_model_store::create(record, m_found_set, fields, column_index_key, m_allow_view, m_find_mode);
     }
     else
     {
@@ -922,13 +906,11 @@ void DbAddDel::construct_specified_columns()
       //  g_warning("  field: %s", (iter->get_name().c_str());
       //}
 
-      Glib::RefPtr<DbTreeModel> liststore = Glib::RefPtr<DbTreeModel>();
-      m_refListStore = liststore.operator->();
-      m_refListStore_as_model = liststore;
+      m_refListStore = Glib::RefPtr<type_model_store>();
     }
   }
  
-  m_TreeView.set_model(m_refListStore_as_model);
+  m_TreeView.set_model(m_refListStore);
 
 
   //Remove all View columns:
@@ -1048,7 +1030,7 @@ bool DbAddDel::refresh_from_database()
     if(m_TreeView.get_model())
       gtk_tree_view_set_model(m_TreeView.gobj(), 0); //This gives the same warning.
 
-    m_TreeView.set_model(m_refListStore_as_model);
+    m_TreeView.set_model(m_refListStore);
     return result;
   }
   else
@@ -1058,6 +1040,9 @@ bool DbAddDel::refresh_from_database()
 
 bool DbAddDel::refresh_from_database_blank()
 {
+  if(m_find_mode)
+    return refresh_from_database();
+
   if(m_refListStore)
   {
     m_refListStore->clear(); //Remove all rows.
@@ -1406,11 +1391,14 @@ DbAddDel::InnerIgnore::~InnerIgnore()
 
 Gnome::Gda::Value DbAddDel::treeview_get_key(const Gtk::TreeModel::iterator& row) const
 {
-  Glib::RefPtr<DbTreeModel> dbmodel = Glib::RefPtr<DbTreeModel>::cast_dynamic(m_refListStore_as_model);
-  if(dbmodel)
-    return dbmodel->get_key_value(row);
-  else
-    return Gnome::Gda::Value();
+  Gnome::Gda::Value value;
+
+  if(m_refListStore)
+  {
+    return m_refListStore->get_key_value(row);
+  }
+
+  return value;
 }
 
 void DbAddDel::on_treeview_cell_edited_bool(const Glib::ustring& path_string, int model_column_index, int data_model_column_index)
@@ -1426,7 +1414,7 @@ void DbAddDel::on_treeview_cell_edited_bool(const Glib::ustring& path_string, in
   const Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_refListStore_as_model->get_iter(path);
+  Gtk::TreeModel::iterator iter = m_refListStore->get_iter(path);
   if(iter)
   {
     Gtk::TreeModel::Row row = *iter;
@@ -1450,7 +1438,7 @@ void DbAddDel::on_treeview_cell_edited_bool(const Glib::ustring& path_string, in
     bool bIsAdd = false;
     bool bIsChange = false;
 
-    const int iCount = m_refListStore_as_model->children().size();
+    const int iCount = m_refListStore->children().size();
     if(iCount)
     {
       if(get_allow_user_actions()) //If add is possible:
@@ -1503,13 +1491,13 @@ void DbAddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const G
   if(path_string.empty())
     return;
 
-  if(!m_refListStore_as_model)
+  if(!m_refListStore)
     return;
 
   const Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_refListStore_as_model->get_iter(path);
+  Gtk::TreeModel::iterator iter = m_refListStore->get_iter(path);
   if(iter != get_model()->children().end())
   {
     Gtk::TreeModel::Row row = *iter;
@@ -1829,11 +1817,11 @@ DbAddDel::type_vecStrings DbAddDel::get_columns_order() const
 
 Glib::RefPtr<Gtk::TreeModel> DbAddDel::get_model()
 {
-  return m_refListStore_as_model;
+  return m_refListStore;
 }
 Glib::RefPtr<const Gtk::TreeModel> DbAddDel::get_model() const
 {
-  return m_refListStore_as_model;
+  return m_refListStore;
 }
 
 bool DbAddDel::get_is_first_row(const Gtk::TreeModel::iterator& iter) const
@@ -1890,10 +1878,7 @@ void DbAddDel::set_value_key(const Gtk::TreeModel::iterator& iter, const Gnome::
       //row[*m_modelcolumn_placeholder] = false;
     }
 
-    //TODO_Performance: Cache the dynamic_cast<>ed result?
-    Glib::RefPtr<DbTreeModel> dbmodel = Glib::RefPtr<DbTreeModel>::cast_dynamic(m_refListStore_as_model);
-    if(dbmodel)
-      return dbmodel->set_key_value(iter, value);
+    m_refListStore->set_key_value(iter, value);
   }
 }
 
@@ -1909,10 +1894,10 @@ bool DbAddDel::get_is_placeholder_row(const Gtk::TreeModel::iterator& iter) cons
   if(!iter)
     return false;
 
-  if(!m_refListStore_as_model)
+  if(!m_refListStore)
     return false;
 
-  if(iter == m_refListStore_as_model->children().end())
+  if(iter == m_refListStore->children().end())
   {
     return false;
   }
@@ -1976,22 +1961,11 @@ void DbAddDel::set_key_field(const sharedptr<Field>& field)
 
 void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter, int model_column_index, int data_model_column_index)
 {
-  if(!m_refListStore_as_model)
-    return;
-
-  //std::cout << "debug: DbAddDel::treeviewcolumn_on_cell_data(): model columns count=" << m_refListStore_as_model->get_n_columns() << std::endl; 
+  //std::cout << "debug: DbAddDel::treeviewcolumn_on_cell_data()" << std::endl; 
 
 
   if(iter)
   {
-    /*
-    if(!iter->get_model_gobject())
-    {
-      std::cerr << "DbAddDel::treeviewcolumn_on_cell_data(): iter has no model" << std::endl;
-      return; 
-    }
-    */
-
     const DbAddDelColumnInfo& column_info = m_ColumnTypes[model_column_index];
 
     sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(column_info.m_item);
@@ -2085,10 +2059,10 @@ bool DbAddDel::get_allow_view_details() const
 
 void DbAddDel::on_cell_button_clicked(const Gtk::TreeModel::Path& path)
 {
-  if(!m_refListStore_as_model)
+  if(!m_refListStore)
     return;
 
-  Gtk::TreeModel::iterator iter = m_refListStore_as_model->get_iter(path);
+  Gtk::TreeModel::iterator iter = m_refListStore->get_iter(path);
   if(iter)
   {
     select_item(iter, false /* start_editing */);
@@ -2191,16 +2165,16 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
 
   if(!Conversions::value_is_empty(parent_primary_key_value)) //If the record's primary key is filled in:
   {
+    Glib::ustring table_name = m_found_set.m_table_name;
+    sharedptr<Field> primary_key_field;
+    Gnome::Gda::Value primary_key_value;
+    Gtk::Window* window = get_application();
+
     //Just update the record:
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
 #endif // GLIBMM_EXCEPTIONS_ENABLED
     {
-      
-      Glib::ustring table_name = m_found_set.m_table_name;
-      sharedptr<Field> primary_key_field;
-      Gnome::Gda::Value primary_key_value;
-
       if(!layout_field->get_has_relationship_name())
       {
         table_name = m_found_set.m_table_name;
@@ -2260,7 +2234,6 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
       LayoutFieldInRecord field_in_record(layout_field, m_found_set.m_table_name /* parent */, primary_key_field, primary_key_value);
 
       //Check whether the value meets uniqueness constraints:
-      Gtk::Window* window = get_application();
       if(!check_entered_value_for_uniqueness(m_found_set.m_table_name, row, layout_field, field_value, window))
       {
         //Revert to the value in the database:
@@ -2280,7 +2253,9 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
       if(!bTest)
       {
         //Update failed.
-        fill_from_database(); //Replace with correct values.
+        //Replace with correct values.
+        const Gnome::Gda::Value value_old = get_field_value_in_database(field_in_record, window);
+        set_entered_field_data(row, layout_field, value_old);
       }
       else
         signal_record_changed().emit();
@@ -2289,10 +2264,26 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
     catch(const Glib::Exception& ex)
     {
       handle_error(ex);
+
+      //Replace with correct values.
+      if(primary_key_field)
+      {
+        LayoutFieldInRecord field_in_record(layout_field, m_found_set.m_table_name /* parent */, primary_key_field, primary_key_value);
+        const Gnome::Gda::Value value_old = get_field_value_in_database(field_in_record, window);
+        set_entered_field_data(row, layout_field, value_old);
+      }
     }
     catch(const std::exception& ex)
     {
       handle_error(ex);
+
+      //Replace with correct values.
+      if(primary_key_field)
+      {
+        LayoutFieldInRecord field_in_record(layout_field, m_found_set.m_table_name /* parent */, primary_key_field, primary_key_value);
+        const Gnome::Gda::Value value_old = get_field_value_in_database(field_in_record, window);
+        set_entered_field_data(row, layout_field, value_old);
+      }
     }
 #endif // GLIBMM_EXCEPTIONS_ENABLED
   }
@@ -2471,6 +2462,11 @@ Gnome::Gda::Value DbAddDel::get_primary_key_value(const Gtk::TreeModel::iterator
   return get_value_key(row);
 }
 
+Gtk::TreeModel::iterator DbAddDel::get_row_selected()
+{
+  return get_item_selected();
+}
+
 } //namespace Glom
 
 
