@@ -110,6 +110,7 @@ bool ImageGlom::on_button_press_event(GdkEventButton *event)
     else
 #endif // !GLOM_ENABLE_CLIENT_ONLY
     {
+      // We cannot be in developer mode in client only mode.
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
@@ -250,9 +251,9 @@ Gnome::Gda::Value ImageGlom::get_value() const
       buffer = 0;
     }
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
-    catch(const Glib::Exception& /* ex */)
+    catch(const Glib::Exception& ex)
     {
-
+      std::cerr << "ImageGlom::get_value(): " << ex.what() << std::endl;
     }
 #endif // GLIBMM_EXCEPTIONS_ENABLED
   }
@@ -378,7 +379,7 @@ void ImageGlom::on_menupopup_activate_select_file()
   if(m_read_only)
     return;
 
-  Gtk::FileChooserDialog dialog(_("Choose image"), Gtk::FILE_CHOOSER_ACTION_OPEN);
+  Gtk::FileChooserDialog dialog(_("Choose Image"), Gtk::FILE_CHOOSER_ACTION_OPEN);
 
   //Get image formats only:
   Gtk::FileFilter filter;
